@@ -1,8 +1,8 @@
 package IPC::SRLock;
 
 use 5.010001;
-use namespace::sweep;
-use version; our $VERSION = qv( sprintf '0.22.%d', q$Rev: 1 $ =~ /\d+/gmx );
+use namespace::autoclean;
+use version; our $VERSION = qv( sprintf '0.23.%d', q$Rev: 1 $ =~ /\d+/gmx );
 
 use Moo;
 use File::DataClass::Types  qw( HashRef LoadableClass Object );
@@ -65,7 +65,7 @@ IPC::SRLock - Set/reset locking semantics to single thread processes
 
 =head1 Version
 
-This documents version v0.22.$Rev: 1 $ of L<IPC::SRLock>
+This documents version v0.23.$Rev: 1 $ of L<IPC::SRLock>
 
 =head1 Synopsis
 
